@@ -100,6 +100,12 @@ public class HistoryFragment extends BrowserFragment implements IRefreshable, Sw
         return v;
     }
 
+    @Override
+    public void onResume() {
+        super.onResume();
+        focusHelper(mHistoryAdapter.isEmpty());
+    }
+
     @Override
     public void onDestroy() {
         mHistoryAdapter.release();
