@@ -24,13 +24,11 @@ import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.R;
-import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.audio.AudioService;
 import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.audio.AudioUtil;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.BitmapCache;
-import org.videolan.vlc.util.Logcat;
 import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCInstance;
 
@@ -41,11 +39,9 @@ import android.content.DialogInterface;
 import android.content.Intent;
 import android.content.SharedPreferences;
 import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
-import android.graphics.Color;
 import android.graphics.drawable.Drawable.ConstantState;
 import android.os.Build;
 import android.os.Bundle;
-import android.os.Environment;
 import android.preference.CheckBoxPreference;
 import android.preference.EditTextPreference;
 import android.preference.ListPreference;
@@ -57,7 +53,6 @@ import android.preference.PreferenceGroup;
 import android.preference.PreferenceManager;
 import android.preference.PreferenceScreen;
 import android.support.v7.widget.Toolbar;
-import android.text.format.DateFormat;
 import android.util.TypedValue;
 import android.view.LayoutInflater;
 import android.view.View;
@@ -81,6 +76,9 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
+        /* Theme must be applied before super.onCreate */
+        applyTheme();
+
         super.onCreate(savedInstanceState);
         addPreferencesFromResource(R.xml.preferences);
 
@@ -146,6 +144,9 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
                     @Override
                     public boolean onPreferenceClick(Preference preference) {
                         setResult(RESULT_RESTART);
+                        Intent intent = getIntent();
+                        finish();
+                        startActivity(intent);
                         return true;
                     }
                 });
@@ -235,13 +236,14 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
             group.removePreference(aoutPref);
         }
         // Video output
-        ListPreference voutPref = (ListPreference) findPreference("vout");
-        int voutEntriesId = LibVlcUtil.isGingerbreadOrLater() ? R.array.vouts : R.array.vouts_froyo;
-        int voutEntriesIdValues = LibVlcUtil.isGingerbreadOrLater() ? R.array.vouts_values : R.array.vouts_values_froyo;
-        voutPref.setEntries(voutEntriesId);
-        voutPref.setEntryValues(voutEntriesIdValues);
-        if (voutPref.getValue() == null)
-            voutPref.setValue("0" /* VOUT_ANDROID_SURFACE */);
+//        FIXME : This setting is disable until OpenGL it's fixed
+//        ListPreference voutPref = (ListPreference) findPreference("vout");
+//        int voutEntriesId = LibVlcUtil.isGingerbreadOrLater() ? R.array.vouts : R.array.vouts_froyo;
+//        int voutEntriesIdValues = LibVlcUtil.isGingerbreadOrLater() ? R.array.vouts_values : R.array.vouts_values_froyo;
+//        voutPref.setEntries(voutEntriesId);
+//        voutPref.setEntryValues(voutEntriesIdValues);
+//        if (voutPref.getValue() == null)
+//            voutPref.setValue("0"  VOUT_ANDROID_SURFACE );
         // Set locale
         EditTextPreference setLocalePref = (EditTextPreference) findPreference("set_locale");
         setLocalePref.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
@@ -276,6 +278,14 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
         sharedPrefs.registerOnSharedPreferenceChangeListener(this);
     }
 
+    private void applyTheme() {
+        SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(this);
+        boolean enableBlackTheme = pref.getBoolean("enable_black_theme", false);
+        if (enableBlackTheme) {
+            setTheme(R.style.Theme_VLC_Black);
+        }
+    }
+
     @Override
     protected void onPostCreate(Bundle savedInstanceState) {
         super.onPostCreate(savedInstanceState);
@@ -287,6 +297,8 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
             root.addView(bar, 0); // insert at top
         } else {
             ViewGroup root = (ViewGroup) findViewById(android.R.id.content);
+            if (!(root.getChildAt(0) instanceof ListView))
+                return;
             ListView content = (ListView) root.getChildAt(0);
 
             root.removeAllViews();
@@ -307,7 +319,6 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
             root.addView(content);
         }
         bar.setTitle(R.string.preferences);
-        bar.setTitleTextColor(Util.getColorFromAttribute(this, R.attr.font_actionbar_selected));
 
         bar.setNavigationOnClickListener(new View.OnClickListener() {
             @Override
