@@ -170,7 +170,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         getActivity().registerReceiver(messageReceiverVideoListFragment, filter);
         Log.i(TAG, "mMediaLibrary.isWorking() " + Boolean.toString(mMediaLibrary.isWorking()));
         if (mMediaLibrary.isWorking()) {
-        	Util.actionScanStart();
+            Util.actionScanStart();
         }
 
         mAnimator = new VideoGridAnimator(mGridView);
@@ -194,8 +194,10 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         final boolean refresh = mVideoAdapter.isEmpty();
         if (refresh)
             updateList();
-        else
+        else {
             mViewNomedia.setVisibility(View.GONE);
+            focusHelper(false);
+        }
         //Get & set times
         HashMap<String, Long> times = MediaDatabase.getInstance().getVideoTimes(getActivity());
         mVideoAdapter.setTimes(times);
@@ -269,6 +271,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
     @Override
     public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
         MediaWrapper media = mVideoAdapter.getItem(position);
+        if (media == null)
+            return;
         if (media instanceof MediaGroup) {
             MainActivity activity = (MainActivity)getActivity();
             VideoGridFragment frag = (VideoGridFragment)activity.showSecondaryFragment("videoGroupList");
@@ -290,6 +294,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
 
     private boolean handleContextItemSelected(MenuItem menu, int position) {
         MediaWrapper media = mVideoAdapter.getItem(position);
+        if (media == null)
+            return false;
         switch (menu.getItemId())
         {
         case R.id.video_list_play_from_start:
@@ -329,7 +335,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         // Do not show the menu of media group.
         AdapterContextMenuInfo info = (AdapterContextMenuInfo)menuInfo;
         MediaWrapper media = mVideoAdapter.getItem(info.position);
-        if (media instanceof MediaGroup)
+        if (media == null || media instanceof MediaGroup)
             return;
         MenuInflater inflater = getActivity().getMenuInflater();
         inflater.inflate(R.menu.video_list, menu);
@@ -371,6 +377,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         PopupMenu popupMenu = new PopupMenu(getActivity(), anchor);
         popupMenu.getMenuInflater().inflate(R.menu.video_list, popupMenu.getMenu());
         MediaWrapper media = mVideoAdapter.getItem(position);
+        if (media == null)
+            return;
         setContextMenuItems(popupMenu.getMenu(), media);
         popupMenu.setOnMenuItemClickListener(new OnMenuItemClickListener() {
             @Override
@@ -510,7 +518,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
 
     @Override
     public void onRefresh() {
-        if (getActivity()!=null)
+        if (getActivity()!=null && !MediaLibrary.getInstance().isWorking())
             MediaLibrary.getInstance().loadMediaItems(getActivity(), true);
     }
 
